@@ -120,9 +120,7 @@ class TflStatus(QtGui.QMainWindow):
         try:
             # load the save file into a temp dict
             self.tubeStatus_list = cPickle.loads(str(self.settings.value("tubeStatus_list").toString()))
-            temp = cPickle.loads(str(self.settings.value("tubeMessages_list").toString()))
-            if(temp != ""):
-	      self.tubeMessages_list = temp
+            self.tubeMessages_list = cPickle.loads(str(self.settings.value("tubeMessages_list").toString()))
 	      
             self.lastUpdate = cPickle.loads(str(self.settings.value("Update Time").toString()))
         except:
@@ -131,24 +129,23 @@ class TflStatus(QtGui.QMainWindow):
 	
     def getStatus(self):
         if( (time.time() - self.lastUpdate) > CACHE_TIMEOUT ):
-    	    print "refresh cache"
+            print "refresh cache"
 
-	    self.progress.setLabelText("Getting current status")
-	    response = minidom.parse(urllib.urlopen(url))
-	    lineNode = response.getElementsByTagName('line')
-	    for nodes in range(lineNode.length):
-		    names = lineNode[nodes].getElementsByTagName('name')
-		    status = lineNode[nodes].getElementsByTagName('status')
-		    messageNode = lineNode[nodes].getElementsByTagName('messages')
+        self.progress.setLabelText("Getting current status")
+        response = minidom.parse(urllib.urlopen(url))
+        lineNode = response.getElementsByTagName('line')
+        for nodes in range(lineNode.length):
+            names = lineNode[nodes].getElementsByTagName('name')
+            status = lineNode[nodes].getElementsByTagName('status')
+            messageNode = lineNode[nodes].getElementsByTagName('messages')
 
-		    fullMessage = ""
-		    for messages in range(messageNode.length):
-		        message = messageNode[messages].getElementsByTagName('message')
-		        if(message):
-    			    fullMessage = fullMessage + "\n" + message[0].firstChild.data
+            fullMessage = status[0].firstChild.data.upper()
+            for messages in range(messageNode.length):
+                message = messageNode[messages].getElementsByTagName('message')
+                if(message):
+                  fullMessage = fullMessage + "\n" + message[0].firstChild.data
 
-            if (fullMessage != ""):
-                self.tubeMessages_list[names[0].firstChild.data] = fullMessage
+            self.tubeMessages_list[names[0].firstChild.data] = fullMessage
             self.tubeStatus_list[names[0].firstChild.data] = status[0].firstChild.data
 
         self.progress.setLabelText("Saving refreshed values")
